/***************************************************************
From the book "Motif Programming, The Essentials...and More"
by Marshall Brain.
Published by Digital Press, ISBN 1-55558-089-0.
To order the book, call 1-800-DIGITAL and ask for EY-J816E-DP.

Copyright 1992, by Digital Equipment Corp.

This code demonstrates the toggle widget in a menu.
***************************************************************/

/* toggle_menu.c */

#include <Xm/Xm.h>
#include <Xm/Label.h> 
#include <Xm/Form.h>
#include <Xm/PushB.h>
#include <Xm/RowColumn.h>
#include <Xm/CascadeB.h>
#include <Xm/ToggleB.h>

XtAppContext context;
XmStringCharSet char_set=XmSTRING_DEFAULT_CHARSET;

Widget toplevel, form, label, menu_bar;
Widget font_menu;
Widget font1_item;
Widget font2_item;
Widget font3_item;

void menuCB(w,client_data,call_data)
    Widget w;
    char *client_data;
    XmAnyCallbackStruct *call_data;
/* callback routine used for all menus */
{
    printf("%s\n",client_data);
    if (strcmp(client_data,"Quit")==0) /* if quit seen, then exit */
        exit(0);
}


Widget make_menu_toggle(item_name,
  client_data,menu)
    char *item_name;
    caddr_t client_data;
    Widget menu;
/* adds a toggle item into a menu. */
{
    int ac;
    Arg al[10];
    Widget item;

    ac = 0;
    XtSetArg(al[ac],XmNlabelString, XmStringCreateLtoR(item_name,
         char_set)); ac++;
    item=XmCreateToggleButton(menu, item_name,al,ac);
    XtManageChild(item);
    XtAddCallback(item, XmNvalueChangedCallback,menuCB, client_data);
    XtSetSensitive(item,True);
    return(item);
}

Widget make_menu(menu_name,menu_bar)
    char *menu_name; 
    Widget menu_bar;
/* creates a menu on the menu bar */
{
    int ac;
    Arg al[10];
    Widget menu, cascade;

    menu=XmCreatePulldownMenu(menu_bar,menu_name,NULL,0);
    ac=0;
    XtSetArg (al[ac],XmNsubMenuId, menu); ac++;
    XtSetArg(al[ac],XmNlabelString,
        XmStringCreateLtoR(menu_name,char_set)); ac++;
    cascade=XmCreateCascadeButton(menu_bar,menu_name,al,ac);  
    XtManageChild(cascade); 
    return(menu);
}

void create_menus(menu_bar)
    Widget menu_bar;
/* creates all the menus for this program */
{
    Arg al[10];
    int ac;

    font_menu=make_menu("Font", menu_bar);
    font1_item=make_menu_toggle ("Font 1","Font 1 selected", font_menu);
    font2_item=make_menu_toggle ("Font 2","Font 2 selected", font_menu);
    font3_item=make_menu_toggle ("Font 3","Font 3 selected", font_menu);
    ac=0;
    XtSetArg(al[ac],XmNradioBehavior, True); ac++;
    XtSetValues(font_menu,al,ac);
}

void main(argc,argv)
    int argc; 
    char *argv[];
{
    Arg al[10];
    int ac;

    /* create the toplevel shell */
    toplevel = XtAppInitialize(&context,"",NULL,0,&argc,argv,NULL,NULL,0);

    /* resize the window */
    ac=0;
    XtSetArg(al[ac],XmNheight,200); ac++;
    XtSetArg(al[ac],XmNwidth,200); ac++;
    XtSetValues(toplevel,al,ac);

    /* create a form widget */
    ac=0;
    form=XmCreateForm(toplevel,"form",al,ac);
    XtManageChild(form);

    /* create a label widget */
    ac=0;
    XtSetArg(al[ac],XmNlabelString,
        XmStringCreate("I'm a label", char_set)); ac++;
    label=XmCreateLabel(form,"label",al,ac);
    XtManageChild(label);

    /* create the menu bar */
    ac=0;
    menu_bar=XmCreateMenuBar(form,"menu_bar",al,ac);
    XtManageChild(menu_bar);

    /* attach the menu bar to the form */
    ac=0;
    XtSetArg(al[ac],XmNtopAttachment,XmATTACH_FORM); ac++;
    XtSetArg(al[ac],XmNrightAttachment,XmATTACH_FORM); ac++;
    XtSetArg(al[ac],XmNleftAttachment,XmATTACH_FORM); ac++;
    XtSetValues(menu_bar,al,ac);

    /* attach the label to the form */
    ac=0;
    XtSetArg(al[ac],XmNtopAttachment,XmATTACH_WIDGET); ac++;
    XtSetArg(al[ac],XmNtopWidget,menu_bar); ac++;
    XtSetArg(al[ac],XmNrightAttachment,XmATTACH_FORM); ac++;
    XtSetArg(al[ac],XmNleftAttachment,XmATTACH_FORM); ac++;
    XtSetArg(al[ac],XmNbottomAttachment,XmATTACH_FORM); ac++;
    XtSetValues(label,al,ac);

    create_menus(menu_bar);

    XtRealizeWidget(toplevel);
    XtAppMainLoop(context);
}
